@@ -12,8 +12,10 @@ the entire library.
 # Checking for VTK9 here even though 8.2 contains vtkmodules.  There
 # are enough idiosyncrasies to VTK 8.2, and supporting it would lead
 # to obscure code.
+
 try:
     from vtkmodules.vtkCommonCore import vtkVersion
+
     VTK9 = vtkVersion().GetVTKMajorVersion() >= 9
 except ImportError:  # pragma: no cover
     VTK9 = False
@@ -134,12 +136,14 @@ if VTK9:
         vtkImageData,
         vtkImplicitFunction,
         vtkMultiBlockDataSet,
+        vtkNonMergingPointLocator,
         vtkPerlinNoise,
         vtkPiecewiseFunction,
         vtkPlane,
         vtkPlaneCollection,
         vtkPlanes,
         vtkPointLocator,
+        vtkPointSet,
         vtkPolyData,
         vtkPolyLine,
         vtkPolyPlane,
@@ -216,6 +220,7 @@ if VTK9:
         vtkShrinkFilter,
         vtkTableBasedClipDataSet,
         vtkTableToPolyData,
+        vtkTessellatorFilter,
         vtkTransformFilter,
         vtkWarpScalar,
         vtkWarpVector,
@@ -332,10 +337,12 @@ if VTK9:
         vtkImageDifference,
         vtkImageExtractComponents,
         vtkImageFlip,
+        vtkImageThreshold,
         vtkRTAnalyticSource,
     )
-    from vtkmodules.vtkImagingGeneral import vtkImageGaussianSmooth
+    from vtkmodules.vtkImagingGeneral import vtkImageGaussianSmooth, vtkImageMedian3D
     from vtkmodules.vtkImagingHybrid import vtkSampleFunction, vtkSurfaceReconstructionFilter
+    from vtkmodules.vtkImagingMorphological import vtkImageDilateErode3D
     from vtkmodules.vtkInteractionWidgets import (
         vtkBoxWidget,
         vtkButtonWidget,
@@ -372,6 +379,7 @@ if VTK9:
     try:
         # Necessary for displaying charts, otherwise crashes on rendering
         import vtkmodules.vtkRenderingContextOpenGL2
+
         _has_vtkRenderingContextOpenGL2 = True
     except ImportError:  # pragma: no cover
         pass
@@ -380,6 +388,7 @@ if VTK9:
         vtkActor,
         vtkActor2D,
         vtkCamera,
+        vtkCellPicker,
         vtkColorTransferFunction,
         vtkCoordinate,
         vtkDataSetMapper,
@@ -393,6 +402,7 @@ if VTK9:
         vtkPolyDataMapper2D,
         vtkPropAssembly,
         vtkProperty,
+        vtkPropPicker,
         vtkRenderedAreaPicker,
         vtkRenderer,
         vtkRenderWindow,
@@ -434,42 +444,58 @@ if VTK9:
     def lazy_vtkGL2PSExporter():
         """Lazy import of the vtkGL2PSExporter."""
         from vtkmodules.vtkIOExportGL2PS import vtkGL2PSExporter
+
         return vtkGL2PSExporter()
 
     def lazy_vtkFacetReader():
         """Lazy import of the vtkFacetReader."""
         from vtkmodules.vtkFiltersHybrid import vtkFacetReader
+
         return vtkFacetReader()
 
     def lazy_vtkPDataSetReader():
         """Lazy import of the vtkPDataSetReader."""
         from vtkmodules.vtkIOParallel import vtkPDataSetReader
+
         return vtkPDataSetReader()
 
     def lazy_vtkMultiBlockPLOT3DReader():
         """Lazy import of the vtkMultiBlockPLOT3DReader."""
         from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
+
         return vtkMultiBlockPLOT3DReader()
 
     def lazy_vtkPlot3DMetaReader():
         """Lazy import of the vtkPlot3DMetaReader."""
         from vtkmodules.vtkIOParallel import vtkPlot3DMetaReader
+
         return vtkPlot3DMetaReader()
 
     def lazy_vtkSegYReader():
         """Lazy import of the vtkSegYReader."""
         from vtkmodules.vtkIOSegY import vtkSegYReader
+
         return vtkSegYReader()
 
+    def lazy_vtkHDFReader():
+        """Lazy import of the vtkHDFReader."""
+        from vtkmodules.vtkIOHDF import vtkHDFReader
+
+        return vtkHDFReader()
+
+    def lazy_vtkCGNSReader():
+        """Lazy import of the vtkCGNSReader."""
+        from vtkmodules.vtkIOCGNSReader import vtkCGNSReader
+
+        return vtkCGNSReader()
+
 else:  # pragma: no cover
 
     # maintain VTK 8.2 compatibility
     try:
         from vtk.vtkCommonKitPython import buffer_shared, vtkAbstractArray, vtkWeakReference
     except ImportError:
-        from vtk.vtkCommonCore import (buffer_shared,
-                                       vtkAbstractArray,
-                                       vtkWeakReference)
+        from vtk.vtkCommonCore import buffer_shared, vtkAbstractArray, vtkWeakReference
 
     import vtk
 
@@ -505,38 +531,55 @@ else:  # pragma: no cover
         """Lazy import of the vtkPlot3DMetaReader."""
         return vtk.vtkPlot3DMetaReader()
 
-    class vtkExplicitStructuredGrid():  # type: ignore
+    def lazy_vtkCGNSReader():
+        """Lazy import of the vtkCGNSReader."""
+        raise VTKVersionError('vtk.CGNSReader requires VTK v9.1.0 or newer')
+
+    class vtkExplicitStructuredGrid:  # type: ignore
         """Empty placeholder for VTK9 compatibility."""
 
         def __init__(self):  # pragma: no cover
             """Raise version error on init."""
             from pyvista.core.errors import VTKVersionError
+
             raise VTKVersionError('vtkHDRReader requires VTK v9 or newer')
 
-    class vtkHDRReader():   # type: ignore
+    class vtkHDRReader:  # type: ignore
         """Empty placeholder for VTK9 compatibility."""
 
         def __init__(self):  # pragma: no cover
             """Raise version error on init."""
             from pyvista.core.errors import VTKVersionError
+
             raise VTKVersionError('vtkHDRReader requires VTK v9 or newer')
 
-    class vtkGLTFReader():   # type: ignore
+    class vtkGLTFReader:  # type: ignore
         """Empty placeholder for VTK9 compatibility."""
 
         def __init__(self):  # pragma: no cover
             """Raise version error on init."""
             from pyvista.core.errors import VTKVersionError
+
             raise VTKVersionError('vtkGLTFReader requires VTK v9 or newer')
 
-    class vtkPythonItem():  # type: ignore
+    class vtkPythonItem:  # type: ignore
         """Empty placeholder for VTK9 compatibility."""
 
         def __init__(self):  # pragma: no cover
             """Raise version error on init."""
             from pyvista.core.errors import VTKVersionError
+
             raise VTKVersionError('Charts requires VTK v9 or newer')
 
+    class vtkHDFReader:  # type: ignore
+        """Empty placeholder for VTK9 compatibility."""
+
+        def __init__(self):  # pragma: no cover
+            """Raise version error on init."""
+            from pyvista.core.errors import VTKVersionError
+
+            raise VTKVersionError('vtkHDFReader requires VTK v9 or newer')
+
 
 # lazy import as this was added in 9.1.0
 def lazy_vtkCameraOrientationWidget():
@@ -544,5 +587,7 @@ def lazy_vtkCameraOrientationWidget():
     try:
         from vtkmodules.vtkInteractionWidgets import vtkCameraOrientationWidget
     except ImportError:  # pragma: no cover
-        raise ImportError('vtkCameraOrientationWidget requires vtk>=9.1.0')
+        from pyvista.core.errors import VTKVersionError
+
+        raise VTKVersionError('vtkCameraOrientationWidget requires vtk>=9.1.0')
     return vtkCameraOrientationWidget()
