@@ -3,11 +3,23 @@
 from .dataset import DataSet, DataObject
 from .composite import MultiBlock
 from .datasetattributes import DataSetAttributes
-from .filters import (CompositeFilters, DataSetFilters, PolyDataFilters,
-                      UnstructuredGridFilters, UniformGridFilters)
+from .filters import (
+    CompositeFilters,
+    DataSetFilters,
+    PolyDataFilters,
+    UnstructuredGridFilters,
+    UniformGridFilters,
+)
 from .grid import Grid, RectilinearGrid, UniformGrid
 from .objects import Table, Texture
-from .pointset import PointGrid, PolyData, StructuredGrid, UnstructuredGrid, ExplicitStructuredGrid
+from .pointset import (
+    PointGrid,
+    PointSet,
+    PolyData,
+    StructuredGrid,
+    UnstructuredGrid,
+    ExplicitStructuredGrid,
+)
 from .pyvista_ndarray import pyvista_ndarray
 from .common_data import perlin_noise
 from .imaging import sample_function
