@@ -8,7 +8,7 @@ import warnings
 
 if sys.version_info >= (3, 8):
     from typing import Literal
-else:
+else:  # pragma: no cover
     from typing_extensions import Literal
 
 import numpy as np
@@ -25,10 +25,11 @@ from pyvista.utilities import (
     transformations,
     vtk_id_list_to_array,
 )
+from pyvista.utilities.common import _coerce_pointslike_arg
 from pyvista.utilities.errors import check_valid_vector
 from pyvista.utilities.misc import PyvistaDeprecationWarning
 
-from .._typing import Vector
+from .._typing import NumericArray, Vector, VectorArray
 from .dataobject import DataObject
 from .datasetattributes import DataSetAttributes
 from .filters import DataSetFilters, _get_output
@@ -88,8 +89,8 @@ class ActiveArrayInfo:
 
     def __eq__(self, other):
         """Check equivalence (useful for serialize/deserialize tests)."""
-        return self.name == other.name and \
-               int(self.association.value) == int(other.association.value)
+        same_association = int(self.association.value) == int(other.association.value)
+        return self.name == other.name and same_association
 
 
 @abstract_class
@@ -163,7 +164,9 @@ class DataSet(DataSetFilters, DataObject):
             self._active_scalars_info = ActiveArrayInfo(field, None)
             for attr in [self.point_data, self.cell_data]:
                 if attr.active_scalars_name is not None:
-                    self._active_scalars_info = ActiveArrayInfo(attr.association, attr.active_scalars_name)
+                    self._active_scalars_info = ActiveArrayInfo(
+                        attr.association, attr.active_scalars_name
+                    )
                     break
 
         return self._active_scalars_info
@@ -391,7 +394,7 @@ class DataSet(DataSetFilters, DataObject):
         return pyvista_ndarray(_points, dataset=self)
 
     @points.setter
-    def points(self, points: np.ndarray):
+    def points(self, points: Union[VectorArray, NumericArray, _vtk.vtkPoints]):
         pdata = self.GetPoints()
         if isinstance(points, pyvista_ndarray):
             # simply set the underlying data
@@ -400,10 +403,15 @@ class DataSet(DataSetFilters, DataObject):
                 pdata.Modified()
                 self.Modified()
                 return
-
+        # directly set the data if vtk object
+        if isinstance(points, _vtk.vtkPoints):
+            self.SetPoints(points)
+            if pdata is not None:
+                pdata.Modified()
+            self.Modified()
+            return
         # otherwise, wrap and use the array
-        if not isinstance(points, np.ndarray):
-            raise TypeError('Points must be a numpy array')
+        points = _coerce_pointslike_arg(points)
         vtk_points = pyvista.vtk_points(points, False)
         if not pdata:
             self.SetPoints(vtk_points)
@@ -446,7 +454,7 @@ class DataSet(DataSetFilters, DataObject):
             raise ValueError('Active vectors are not vectors.')
 
         scale_name = f'{vectors_name} Magnitude'
-        scale = np.linalg.norm(self.active_vectors, axis=1)
+        scale = np.linalg.norm(self.active_vectors, axis=1)  # type: ignore
         self.point_data.set_array(scale, scale_name)
         return self.glyph(orient=vectors_name, scale=scale_name)
 
@@ -459,9 +467,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `DataSet.vectors` is deprecated. "
-            "Use `DataSet.active_vectors` instead.",
-            PyvistaDeprecationWarning
+            "Use of `DataSet.vectors` is deprecated. Use `DataSet.active_vectors` instead.",
+            PyvistaDeprecationWarning,
         )
         return self.active_vectors
 
@@ -470,9 +477,8 @@ class DataSet(DataSetFilters, DataObject):
         warnings.warn(
             "Use of `DataSet.vectors` to add vector data is deprecated. "
             "Use `DataSet['vector_name'] = data`. "
-            "Use `DataSet.active_vectors_name = 'vector_name' to make active."
-            ,
-            PyvistaDeprecationWarning
+            "Use `DataSet.active_vectors_name = 'vector_name' to make active.",
+            PyvistaDeprecationWarning,
         )
         if array.ndim != 2:
             raise ValueError('vector array must be a 2-dimensional array')
@@ -494,18 +500,16 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `DataSet.t_coords` is deprecated. "
-            "Use `DataSet.active_t_coords` instead.",
-            PyvistaDeprecationWarning
+            "Use of `DataSet.t_coords` is deprecated. Use `DataSet.active_t_coords` instead.",
+            PyvistaDeprecationWarning,
         )
         return self.active_t_coords
 
     @t_coords.setter
     def t_coords(self, t_coords: np.ndarray):  # pragma: no cover
         warnings.warn(
-            "Use of `DataSet.t_coords` is deprecated. "
-            "Use `DataSet.active_t_coords` instead.",
-            PyvistaDeprecationWarning
+            "Use of `DataSet.t_coords` is deprecated. Use `DataSet.active_t_coords` instead.",
+            PyvistaDeprecationWarning,
         )
         self.active_t_coords = t_coords  # type: ignore
 
@@ -615,7 +619,7 @@ class DataSet(DataSetFilters, DataObject):
                 mesh.Modified()
         return texture
 
-    def set_active_scalars(self, name: str, preference='cell'):
+    def set_active_scalars(self, name: Optional[str], preference='cell'):
         """Find the scalars by name and appropriately sets it as active.
 
         To deactivate any active scalars, pass ``None`` as the ``name``.
@@ -633,8 +637,7 @@ class DataSet(DataSetFilters, DataObject):
             type.  Can be either ``'cell'`` or ``'point'``.
 
         """
-        if preference not in ['point', 'cell', FieldAssociation.CELL,
-                              FieldAssociation.POINT]:
+        if preference not in ['point', 'cell', FieldAssociation.CELL, FieldAssociation.POINT]:
             raise ValueError('``preference`` must be either "point" or "cell"')
         if name is None:
             self.GetCellData().SetActiveScalars(None)
@@ -656,7 +659,7 @@ class DataSet(DataSetFilters, DataObject):
 
         self._active_scalars_info = ActiveArrayInfo(field, name)
 
-    def set_active_vectors(self, name: str, preference='point'):
+    def set_active_vectors(self, name: Optional[str], preference='point'):
         """Find the vectors by name and appropriately sets it as active.
 
         To deactivate any active vectors, pass ``None`` as the ``name``.
@@ -691,7 +694,7 @@ class DataSet(DataSetFilters, DataObject):
 
         self._active_vectors_info = ActiveArrayInfo(field, name)
 
-    def set_active_tensors(self, name: str, preference='point'):
+    def set_active_tensors(self, name: Optional[str], preference='point'):
         """Find the tensors by name and appropriately sets it as active.
 
         To deactivate any active tensors, pass ``None`` as the ``name``.
@@ -820,9 +823,9 @@ class DataSet(DataSetFilters, DataObject):
             return self.point_data.active_normals
         return self.cell_data.active_normals
 
-    def get_data_range(self,
-                       arr_var: Optional[Union[str, np.ndarray]] = None,
-                       preference='cell') -> Tuple[Union[float, np.ndarray], Union[float, np.ndarray]]:
+    def get_data_range(
+        self, arr_var: Optional[Union[str, np.ndarray]] = None, preference='cell'
+    ) -> Tuple[Union[float, np.ndarray], Union[float, np.ndarray]]:
         """Get the non-NaN min and max of a named array.
 
         Parameters
@@ -862,11 +865,7 @@ class DataSet(DataSetFilters, DataObject):
         return np.nanmin(arr), np.nanmax(arr)
 
     def rotate_x(
-            self,
-            angle: float,
-            point=(0.0, 0.0, 0.0),
-            transform_all_input_vectors=False,
-            inplace=False
+        self, angle: float, point=(0.0, 0.0, 0.0), transform_all_input_vectors=False, inplace=False
     ):
         """Rotate mesh about the x-axis.
 
@@ -915,14 +914,12 @@ class DataSet(DataSetFilters, DataObject):
         """
         check_valid_vector(point, "point")
         t = transformations.axis_angle_rotation((1, 0, 0), angle, point=point, deg=True)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def rotate_y(
-            self,
-            angle: float,
-            point=(0.0, 0.0, 0.0),
-            transform_all_input_vectors=False,
-            inplace=False
+        self, angle: float, point=(0.0, 0.0, 0.0), transform_all_input_vectors=False, inplace=False
     ):
         """Rotate mesh about the y-axis.
 
@@ -971,14 +968,12 @@ class DataSet(DataSetFilters, DataObject):
         """
         check_valid_vector(point, "point")
         t = transformations.axis_angle_rotation((0, 1, 0), angle, point=point, deg=True)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def rotate_z(
-            self,
-            angle: float,
-            point=(0.0, 0.0, 0.0),
-            transform_all_input_vectors=False,
-            inplace=False
+        self, angle: float, point=(0.0, 0.0, 0.0), transform_all_input_vectors=False, inplace=False
     ):
         """Rotate mesh about the z-axis.
 
@@ -1027,15 +1022,17 @@ class DataSet(DataSetFilters, DataObject):
         """
         check_valid_vector(point, "point")
         t = transformations.axis_angle_rotation((0, 0, 1), angle, point=point, deg=True)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def rotate_vector(
-            self,
-            vector: Iterable[float],
-            angle: float,
-            point=(0.0, 0.0, 0.0),
-            transform_all_input_vectors=False,
-            inplace=False
+        self,
+        vector: Iterable[float],
+        angle: float,
+        point=(0.0, 0.0, 0.0),
+        transform_all_input_vectors=False,
+        inplace=False,
     ):
         """Rotate mesh about a vector.
 
@@ -1088,9 +1085,13 @@ class DataSet(DataSetFilters, DataObject):
         check_valid_vector(vector)
         check_valid_vector(point, "point")
         t = transformations.axis_angle_rotation(vector, angle, point=point, deg=True)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
-    def translate(self, xyz: Union[list, tuple, np.ndarray], transform_all_input_vectors=False, inplace=False):
+    def translate(
+        self, xyz: Union[list, tuple, np.ndarray], transform_all_input_vectors=False, inplace=False
+    ):
         """Translate the mesh.
 
         .. note::
@@ -1131,9 +1132,13 @@ class DataSet(DataSetFilters, DataObject):
         """
         transform = _vtk.vtkTransform()
         transform.Translate(xyz)
-        return self.transform(transform, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            transform, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
-    def scale(self, xyz: Union[list, tuple, np.ndarray], transform_all_input_vectors=False, inplace=False):
+    def scale(
+        self, xyz: Union[list, tuple, np.ndarray], transform_all_input_vectors=False, inplace=False
+    ):
         """Scale the mesh.
 
         .. note::
@@ -1178,7 +1183,9 @@ class DataSet(DataSetFilters, DataObject):
         """
         transform = _vtk.vtkTransform()
         transform.Scale(xyz)
-        return self.transform(transform, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            transform, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def flip_x(self, point=None, transform_all_input_vectors=False, inplace=False):
         """Flip mesh about the x-axis.
@@ -1226,7 +1233,9 @@ class DataSet(DataSetFilters, DataObject):
             point = self.center
         check_valid_vector(point, 'point')
         t = transformations.reflection((1, 0, 0), point=point)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def flip_y(self, point=None, transform_all_input_vectors=False, inplace=False):
         """Flip mesh about the y-axis.
@@ -1274,7 +1283,9 @@ class DataSet(DataSetFilters, DataObject):
             point = self.center
         check_valid_vector(point, 'point')
         t = transformations.reflection((0, 1, 0), point=point)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def flip_z(self, point=None, transform_all_input_vectors=False, inplace=False):
         """Flip mesh about the z-axis.
@@ -1322,9 +1333,13 @@ class DataSet(DataSetFilters, DataObject):
             point = self.center
         check_valid_vector(point, 'point')
         t = transformations.reflection((0, 0, 1), point=point)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
-    def flip_normal(self, normal: List[float], point=None, transform_all_input_vectors=False, inplace=False):
+    def flip_normal(
+        self, normal: List[float], point=None, transform_all_input_vectors=False, inplace=False
+    ):
         """Flip mesh about the normal.
 
         .. note::
@@ -1374,7 +1389,9 @@ class DataSet(DataSetFilters, DataObject):
         check_valid_vector(normal, 'normal')
         check_valid_vector(point, 'point')
         t = transformations.reflection(normal, point=point)
-        return self.transform(t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace)
+        return self.transform(
+            t, transform_all_input_vectors=transform_all_input_vectors, inplace=inplace
+        )
 
     def copy_meta_from(self, ido: 'DataSet'):
         """Copy pyvista meta data onto this object from another object.
@@ -1399,9 +1416,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `point_arrays` is deprecated. "
-            "Use `point_data` instead.",
-            PyvistaDeprecationWarning
+            "Use of `point_arrays` is deprecated. Use `point_data` instead.",
+            PyvistaDeprecationWarning,
         )
         return self.point_data
 
@@ -1441,8 +1457,9 @@ class DataSet(DataSetFilters, DataObject):
         (8,)
 
         """
-        return DataSetAttributes(self.GetPointData(), dataset=self,
-                                 association=FieldAssociation.POINT)
+        return DataSetAttributes(
+            self.GetPointData(), dataset=self, association=FieldAssociation.POINT
+        )
 
     def clear_point_arrays(self):  # pragma: no cover
         """Remove all point data.
@@ -1452,9 +1469,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `clear_point_arrays` is deprecated. "
-            "Use `clear_point_data` instead.",
-            PyvistaDeprecationWarning
+            "Use of `clear_point_arrays` is deprecated. Use `clear_point_data` instead.",
+            PyvistaDeprecationWarning,
         )
         self.clear_point_data()
 
@@ -1485,9 +1501,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `clear_cell_arrays` is deprecated. "
-            "Use `clear_cell_data` instead.",
-            PyvistaDeprecationWarning
+            "Use of `clear_cell_arrays` is deprecated. Use `clear_cell_data` instead.",
+            PyvistaDeprecationWarning,
         )
         self.clear_cell_data()
 
@@ -1503,9 +1518,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `clear_arrays` is deprecated. "
-            "Use `clear_data` instead.",
-            PyvistaDeprecationWarning
+            "Use of `clear_arrays` is deprecated. Use `clear_data` instead.",
+            PyvistaDeprecationWarning,
         )
         self.clear_data()
 
@@ -1539,9 +1553,8 @@ class DataSet(DataSetFilters, DataObject):
 
         """
         warnings.warn(
-            "Use of `cell_arrays` is deprecated. "
-            "Use `cell_data` instead.",
-            PyvistaDeprecationWarning
+            "Use of `cell_arrays` is deprecated. Use `cell_data` instead.",
+            PyvistaDeprecationWarning,
         )
         return self.cell_data
 
@@ -1581,8 +1594,9 @@ class DataSet(DataSetFilters, DataObject):
         (6,)
 
         """
-        return DataSetAttributes(self.GetCellData(), dataset=self,
-                                 association=FieldAssociation.CELL)
+        return DataSetAttributes(
+            self.GetCellData(), dataset=self, association=FieldAssociation.CELL
+        )
 
     @property
     def n_points(self) -> int:
@@ -1726,7 +1740,9 @@ class DataSet(DataSetFilters, DataObject):
         sizes = self.compute_cell_sizes(length=False, area=False, volume=True)
         return np.sum(sizes.cell_data['Volume'])
 
-    def get_array(self, name: str, preference: Literal['cell', 'point', 'field']='cell') -> np.ndarray:
+    def get_array(
+        self, name: str, preference: Literal['cell', 'point', 'field'] = 'cell'
+    ) -> np.ndarray:
         """Search both point, cell and field data for an array.
 
         Parameters
@@ -1778,8 +1794,9 @@ class DataSet(DataSetFilters, DataObject):
             raise RuntimeError  # this should never be reached with err=True
         return arr
 
-    def get_array_association(self, name: str,
-                              preference: Literal['cell', 'point', 'field'] = 'cell') -> FieldAssociation:
+    def get_array_association(
+        self, name: str, preference: Literal['cell', 'point', 'field'] = 'cell'
+    ) -> FieldAssociation:
         """Get the association of an array.
 
         Parameters
@@ -1836,8 +1853,10 @@ class DataSet(DataSetFilters, DataObject):
             name = index
             preference = 'cell'
         else:
-            raise KeyError(f'Index ({index}) not understood.'
-                           ' Index must be a string name or a tuple of string name and string preference.')
+            raise KeyError(
+                f'Index ({index}) not understood.'
+                ' Index must be a string name or a tuple of string name and string preference.'
+            )
         return self.get_array(name, preference=preference)
 
     def _ipython_key_completions_(self) -> List[str]:
@@ -1996,8 +2015,10 @@ class DataSet(DataSetFilters, DataObject):
         """
         # Allow child classes to overwrite parent classes
         if not isinstance(self, type(mesh)):
-            raise TypeError(f'The Input DataSet type {type(mesh)} must be '
-                            f'compatible with the one being overwritten {type(self)}')
+            raise TypeError(
+                f'The Input DataSet type {type(mesh)} must be '
+                f'compatible with the one being overwritten {type(self)}'
+            )
         self.deep_copy(mesh)
         if is_pyvista_dataset(mesh):
             self.copy_meta_from(mesh)
@@ -2029,6 +2050,37 @@ class DataSet(DataSetFilters, DataObject):
         alg.Update()
         return _get_output(alg)
 
+    def cast_to_pointset(self, deep: bool = False) -> 'pyvista.PointSet':
+        """Get a new representation of this object as a :class:`pyvista.PointSet`.
+
+        Parameters
+        ----------
+        deep : bool, optional
+            When ``True`` makes a full copy of the object.  When ``False``,
+            performs a shallow copy where the points and data arrays are
+            references to the original object.
+
+        Returns
+        -------
+        pyvista.PointSet
+            Dataset cast into a :class:`pyvista.PointSet`.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> mesh = pyvista.Sphere()
+        >>> pointset = mesh.cast_to_pointset()
+        >>> type(pointset)
+        <class 'pyvista.core.pointset.PointSet'>
+
+        """
+        pset = pyvista.PointSet()
+        pset.SetPoints(self.GetPoints())
+        pset.GetPointData().ShallowCopy(self.GetPointData())
+        if deep:
+            return pset.copy(deep=True)
+        return pset
+
     def find_closest_point(self, point: Iterable[float], n=1) -> int:
         """Find index of closest point in this mesh to the given point.
 
@@ -2051,6 +2103,13 @@ class DataSet(DataSetFilters, DataObject):
         int
             The index of the point in this mesh that is closest to the given point.
 
+        See Also
+        --------
+        DataSet.find_closest_cell
+        DataSet.find_containing_cell
+        DataSet.find_cells_along_line
+        DataSet.find_cells_within_bounds
+
         Examples
         --------
         Find the index of the closest point to ``(0, 1, 0)``.
@@ -2083,26 +2142,47 @@ class DataSet(DataSetFilters, DataObject):
             return vtk_id_list_to_array(id_list)
         return locator.FindClosestPoint(point)
 
-    def find_closest_cell(self, point: Union[int, np.ndarray]) -> Union[int, np.ndarray]:
+    def find_closest_cell(
+        self,
+        point: Union[VectorArray, NumericArray],
+        return_closest_point: bool = False,
+    ) -> Union[int, np.ndarray, Tuple[Union[int, np.ndarray], np.ndarray]]:
         """Find index of closest cell in this mesh to the given point.
 
         Parameters
         ----------
-        point : iterable(float) or np.ndarray
+        point : Sequence(float) or np.ndarray
             Coordinates of point to query (length 3) or a ``numpy`` array of ``n``
             points with shape ``(n, 3)``.
 
+        return_closest_point : bool, optional
+            If ``True``, the closest point within a mesh cell to that point is
+            returned.  This is not necessarily the closest nodal point on the
+            mesh.  Default is ``False``.
+
         Returns
         -------
         int or numpy.ndarray
-            Index or indices of the cell in this mesh that is closest
-            to the given point.
+            Index or indices of the cell in this mesh that is/are closest
+            to the given point(s).
+
+        numpy.ndarray
+            Point or points inside a cell of the mesh that is/are closest
+            to the given point(s).  Only returned if
+            ``return_closest_point=True``.
 
         Warnings
         --------
         This method may still return a valid cell index even if the point
         contains a value like ``numpy.inf`` or ``numpy.nan``.
 
+        See Also
+        --------
+        DataSet.find_closest_point
+        DataSet.find_containing_cell
+        DataSet.find_cells_along_line
+        DataSet.find_cells_within_bounds
+
         Examples
         --------
         Find nearest cell on a sphere centered on the
@@ -2133,38 +2213,122 @@ class DataSet(DataSetFilters, DataObject):
         >>> indices.shape
         (5000,)
 
+        For the closest cell, find the point inside the cell that is
+        closest to the supplied point.  The rectangle is a unit square
+        with 1 cell and 4 nodal points at the corners in the plane with
+        ``z`` normal and ``z=0``.  The closest point inside the cell is
+        not usually at a nodal point.
+
+        >>> unit_square = pyvista.Rectangle()
+        >>> index, closest_point = unit_square.find_closest_cell(
+        ...     [0.25, 0.25, 0.5],
+        ...     return_closest_point=True
+        ... )
+        >>> closest_point
+        array([0.25, 0.25, 0.  ])
+
+        But, the closest point can be a nodal point, although the index of
+        that point is not returned.  If the closest nodal point by index is
+        desired, see :func:`DataSet.find_closest_point`.
+
+        >>> index, closest_point = unit_square.find_closest_cell(
+        ...     [1.0, 1.0, 0.5],
+        ...     return_closest_point=True
+        ... )
+        >>> closest_point
+        array([1., 1., 0.])
+
         """
-        if isinstance(point, collections.abc.Sequence):
-            point = np.array(point)
-        # check if this is an array of points
-        if isinstance(point, np.ndarray):
-            if point.ndim > 2:
-                raise ValueError("Array of points must be 2D")
-            if point.ndim == 2:
-                if point.shape[1] != 3:
-                    raise ValueError("Array of points must have three values per point")
-            else:
-                if point.size != 3:
-                    raise ValueError("Given point must have three values")
-                point = np.array([point])
-        else:
-            raise TypeError("Given point must be an iterable or an array.")
+        point = _coerce_pointslike_arg(point, copy=False)
 
         locator = _vtk.vtkCellLocator()
         locator.SetDataSet(self)
         locator.BuildLocator()
 
         cell = _vtk.vtkGenericCell()
-        closest_point = [0, 0, 0]
-        cellId = _vtk.mutable(0)
-        subld = _vtk.mutable(0)
-        dist2 = _vtk.mutable(0.0)
 
-        closest_cells = []
+        closest_cells: List[int] = []
+        closest_points: List[List[float]] = []
+
         for node in point:
-            locator.FindClosestPoint(node, closest_point, cell, cellId, subld, dist2)
-            closest_cells.append(int(cellId))
-        return closest_cells[0] if len(closest_cells) == 1 else np.array(closest_cells)
+            closest_point = [0.0, 0.0, 0.0]
+            cell_id = _vtk.mutable(0)
+            sub_id = _vtk.mutable(0)
+            dist2 = _vtk.mutable(0.0)
+
+            locator.FindClosestPoint(node, closest_point, cell, cell_id, sub_id, dist2)
+            closest_cells.append(int(cell_id))
+            closest_points.append(closest_point)
+
+        out_cells: Union[int, np.ndarray] = (
+            closest_cells[0] if len(closest_cells) == 1 else np.array(closest_cells)
+        )
+        out_points = (
+            np.array(closest_points[0]) if len(closest_points) == 1 else np.array(closest_points)
+        )
+
+        if return_closest_point:
+            return out_cells, out_points
+        return out_cells
+
+    def find_containing_cell(
+        self, point: Union[VectorArray, NumericArray]
+    ) -> Union[int, np.ndarray]:
+        """Find index of a cell that contains the given point.
+
+        Parameters
+        ----------
+        point : Sequence(float) or np.ndarray
+            Coordinates of point to query (length 3) or a ``numpy`` array of ``n``
+            points with shape ``(n, 3)``.
+
+        Returns
+        -------
+        int or numpy.ndarray
+            Index or indices of the cell in this mesh that contains
+            the given point.
+
+        See Also
+        --------
+        DataSet.find_closest_point
+        DataSet.find_closest_cell
+        DataSet.find_cells_along_line
+        DataSet.find_cells_within_bounds
+
+        Examples
+        --------
+        A unit square with 16 equal sized cells is created and a cell
+        containing the point ``[0.3, 0.3, 0.0]`` is found.
+
+        >>> import pyvista
+        >>> mesh = pyvista.UniformGrid(dims=[5, 5, 1], spacing=[1/4, 1/4, 0])
+        >>> mesh
+        UniformGrid...
+        >>> mesh.find_containing_cell([0.3, 0.3, 0.0])
+        5
+
+        A point outside the mesh domain will return ``-1``.
+
+        >>> mesh.find_containing_cell([0.3, 0.3, 1.0])
+        -1
+
+        Find the cells that contain 1000 random points inside the mesh.
+
+        >>> import numpy as np
+        >>> points = np.random.random((1000, 3))
+        >>> indices = mesh.find_containing_cell(points)
+        >>> indices.shape
+        (1000,)
+
+        """
+        point = _coerce_pointslike_arg(point, copy=False)
+
+        locator = _vtk.vtkCellLocator()
+        locator.SetDataSet(self)
+        locator.BuildLocator()
+
+        containing_cells = [locator.FindCell(node) for node in point]
+        return containing_cells[0] if len(containing_cells) == 1 else np.array(containing_cells)
 
     def find_cells_along_line(
         self,
@@ -2193,6 +2357,13 @@ class DataSet(DataSetFilters, DataObject):
             Index or indices of the cell in this mesh that are closest
             to the given point.
 
+        See Also
+        --------
+        DataSet.find_closest_point
+        DataSet.find_closest_cell
+        DataSet.find_containing_cell
+        DataSet.find_cells_within_bounds
+
         Examples
         --------
         >>> import pyvista
@@ -2225,6 +2396,13 @@ class DataSet(DataSetFilters, DataObject):
             Index or indices of the cell in this mesh that are closest
             to the given point.
 
+        See Also
+        --------
+        DataSet.find_closest_point
+        DataSet.find_closest_cell
+        DataSet.find_containing_cell
+        DataSet.find_cells_along_line
+
         Examples
         --------
         >>> import pyvista
@@ -2328,7 +2506,7 @@ class DataSet(DataSetFilters, DataObject):
         Returns
         -------
         int
-            VTK cell type. See <https://vtk.org/doc/nightly/html/vtkCellType_8h_source.html>.
+            VTK cell type. See `vtkCellType.h <https://vtk.org/doc/nightly/html/vtkCellType_8h_source.html>`_ .
 
         Examples
         --------
