@@ -69,6 +69,15 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     association : FieldAssociation
         The array association type of the vtkobject.
 
+    Notes
+    -----
+    When printing out the point arrays, you can see which arrays are
+    the active scalars, vectors, normals, and texture coordinates.
+    In the arrays list, ``SCALARS`` denotes that these are the active
+    scalars, ``VECTORS`` denotes that these arrays are tagged as the
+    active vectors data (i.e. data with magnitude and direction) and
+    so on.
+
     Examples
     --------
     Store data with point association in a DataSet.
@@ -86,6 +95,12 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     >>> mesh.point_data['my_data']
     pyvista_ndarray([0, 0, 0, 0, 0, 0, 0, 0])
 
+    Remove the array.
+
+    >>> del mesh.point_data['my_data']
+    >>> 'my_data' in mesh.point_data
+    False
+
     Print the available arrays from dataset attributes.
 
     >>> import numpy as np
@@ -111,19 +126,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         vectors1                float64  (4, 3)               VECTORS
         vectors0                float64  (4, 3)
 
-    Notes
-    -----
-    When printing out the point arrays, you can see which arrays are
-    the active scalars, vectors, normals, and texture coordinates.
-    In the arrays list, ``SCALARS`` denotes that these are the active
-    scalars, ``VECTORS`` denotes that these arrays are tagged as the
-    active vectors data (i.e. data with magnitude and direction) and
-    so on.
-
     """
 
-    def __init__(self, vtkobject: _vtk.vtkFieldData, dataset: _vtk.vtkDataSet,
-                 association: FieldAssociation):
+    def __init__(
+        self, vtkobject: _vtk.vtkFieldData, dataset: _vtk.vtkDataSet, association: FieldAssociation
+    ):
         """Initialize DataSetAttributes."""
         super().__init__(vtkobject=vtkobject)
         self.dataset = dataset
@@ -138,7 +145,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             for i, (name, array) in enumerate(self.items()):
                 if len(name) > 23:
                     name = f'{name[:20]}...'
-                vtk_arr = array.VTKObject
+                # vtk_arr = array.VTKObject
                 try:
                     arr_type = attr_type[self.IsArrayAnAttribute(i)]
                 except (IndexError, TypeError, AttributeError):  # pragma: no cover
@@ -149,7 +156,9 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
                     if name == self.active_vectors_name:
                         arr_type = 'VECTORS'
 
-                line = f'{name[:23]:<24}{str(array.dtype):<9}{str(array.shape):<20} {arr_type}'.strip()
+                line = (
+                    f'{name[:23]:<24}{str(array.dtype):<9}{str(array.shape):<20} {arr_type}'.strip()
+                )
                 lines.append(line)
             array_info = '\n    ' + '\n    '.join(lines)
 
@@ -272,18 +281,20 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         """
         self._raise_field_data_no_scalars_vectors()
         if self.GetScalars() is not None:
-            return pyvista_ndarray(self.GetScalars(), dataset=self.dataset,
-                                   association=self.association)
+            return pyvista_ndarray(
+                self.GetScalars(), dataset=self.dataset, association=self.association
+            )
         return None
 
     @active_scalars.setter
     def active_scalars(self, name: str):  # pragma: no cover
-        warnings.warn("\n\nUsing active_scalars to set the active scalars has been "
-                      "deprecated.  Use:\n\n"
-                      "  - `DataSetAttributes.set_scalars`\n"
-                      "  - `DataSetAttributes.active_scalars_name`\n"
-                      "  - The [] operator",
-            PyvistaDeprecationWarning
+        warnings.warn(
+            "\n\nUsing active_scalars to set the active scalars has been "
+            "deprecated.  Use:\n\n"
+            "  - `DataSetAttributes.set_scalars`\n"
+            "  - `DataSetAttributes.active_scalars_name`\n"
+            "  - The [] operator",
+            PyvistaDeprecationWarning,
         )
         self.active_scalars_name = name
 
@@ -316,17 +327,17 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         self._raise_field_data_no_scalars_vectors()
         vectors = self.GetVectors()
         if vectors is not None:
-            return pyvista_ndarray(vectors, dataset=self.dataset,
-                                   association=self.association)
+            return pyvista_ndarray(vectors, dataset=self.dataset, association=self.association)
         return None
 
     @active_vectors.setter
     def active_vectors(self, name: str):  # pragma: no cover
-        warnings.warn("\n\nUsing active_vectors to set the active vectors has been "
-                      "deprecated.  Use:\n\n"
-                      "  - `DataSetAttributes.set_vectors`\n"
-                      "  - `DataSetAttributes.active_vectors_name`\n",
-            PyvistaDeprecationWarning
+        warnings.warn(
+            "\n\nUsing active_vectors to set the active vectors has been "
+            "deprecated.  Use:\n\n"
+            "  - `DataSetAttributes.set_vectors`\n"
+            "  - `DataSetAttributes.active_vectors_name`\n",
+            PyvistaDeprecationWarning,
         )
         self.active_vectors_name = name
 
@@ -372,7 +383,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         warnings.warn(
             "Use of `DataSetAttributes.t_coords` is deprecated. "
             "Use `DataSetAttributes.active_t_coords` instead.",
-            PyvistaDeprecationWarning
+            PyvistaDeprecationWarning,
         )
         return self.active_t_coords
 
@@ -381,7 +392,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         warnings.warn(
             "Use of `DataSetAttributes.t_coords` is deprecated. "
             "Use `DataSetAttributes.active_t_coords` instead.",
-            PyvistaDeprecationWarning
+            PyvistaDeprecationWarning,
         )
         self.active_t_coords = t_coords  # type: ignore
 
@@ -424,10 +435,13 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             raise ValueError('Texture coordinates must be a 2-dimensional array')
         valid_length = self.valid_array_len
         if t_coords.shape[0] != valid_length:
-            raise ValueError(f'Number of texture coordinates ({t_coords.shape[0]}) must match number of points ({valid_length})')
+            raise ValueError(
+                f'Number of texture coordinates ({t_coords.shape[0]}) must match number of points ({valid_length})'
+            )
         if t_coords.shape[1] != 2:
-            raise ValueError('Texture coordinates must only have 2 components,'
-                             f' not ({t_coords.shape[1]})')
+            raise ValueError(
+                f'Texture coordinates must only have 2 components, not ({t_coords.shape[1]})'
+            )
         vtkarr = _vtk.numpyTovtkDataArray(t_coords, name='Texture Coordinates')
         self.SetTCoords(vtkarr)
         self.Modified()
@@ -442,9 +456,8 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
 
         """
         warnings.warn(
-            "Use of `active_texture_name` is deprecated. "
-            "Use `active_t_coords_name` instead.",
-            PyvistaDeprecationWarning
+            "Use of `active_texture_name` is deprecated. Use `active_t_coords_name` instead.",
+            PyvistaDeprecationWarning,
         )
         return self.active_t_coords_name
 
@@ -473,7 +486,9 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         if np.issubdtype(dtype, np.number) or dtype == bool:
             self.SetActiveScalars(name)
 
-    def get_array(self, key: Union[str, int]) -> Union[pyvista_ndarray, _vtk.vtkDataArray, _vtk.vtkAbstractArray]:
+    def get_array(
+        self, key: Union[str, int]
+    ) -> Union[pyvista_ndarray, _vtk.vtkDataArray, _vtk.vtkAbstractArray]:
         """Get an array in this object.
 
         Parameters
@@ -496,6 +511,13 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         KeyError
             If the key does not exist.
 
+        Notes
+        -----
+        This is provided since arrays are ordered within VTK and can
+        be indexed via an int.  When getting an array, you can just
+        use the key of the array with the ``[]`` operator with the
+        name of the array.
+
         Examples
         --------
         Store data with point association in a DataSet.
@@ -515,13 +537,6 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         >>> mesh.point_data.get_array('my_data')
         pyvista_ndarray([0, 1, 2, 3, 4, 5, 6, 7])
 
-        Notes
-        -----
-        This is provided since arrays are ordered within VTK and can
-        be indexed via an int.  When getting an array, you can just
-        use the key of the array with the ``[]`` operator with the
-        name of the array.
-
         """
         self._raise_index_out_of_bounds(index=key)
         vtk_arr = self.GetArray(key)
@@ -536,8 +551,9 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             narray = narray.view(np.bool_)  # type: ignore
         return narray
 
-    def set_array(self, data: Union[Sequence[Number], Number, np.ndarray],
-                  name: str, deep_copy=False) -> None:
+    def set_array(
+        self, data: Union[Sequence[Number], Number, np.ndarray], name: str, deep_copy=False
+    ) -> None:
         """Add an array to this object.
 
         Use this method when adding arrays to the DataSet.  If
@@ -562,6 +578,12 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         deep_copy : bool, optional
             When ``True`` makes a full copy of the array.
 
+        Notes
+        -----
+        You can simply use the ``[]`` operator to add an array to the
+        dataset.  Note that this will automatically become the active
+        scalars.
+
         Examples
         --------
         Add a point array to a mesh.
@@ -587,19 +609,14 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         >>> mesh.field_data['my-data']
         pyvista_ndarray([0, 1, 2])
 
-        Notes
-        -----
-        You can simply use the ``[]`` operator to add an array to the
-        dataset.  Note that this will automatically become the active
-        scalars.
-
         """
         vtk_arr = self._prepare_array(data, name, deep_copy)
         self.VTKObject.AddArray(vtk_arr)
         self.VTKObject.Modified()
 
-    def set_scalars(self, scalars: Union[Sequence[Number], Number, np.ndarray],
-                    name='scalars', deep_copy=False):
+    def set_scalars(
+        self, scalars: Union[Sequence[Number], Number, np.ndarray], name='scalars', deep_copy=False
+    ):
         """Set the active scalars of the dataset with an array.
 
         In VTK and PyVista, scalars are a quantity that has no
@@ -649,8 +666,9 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         self.VTKObject.SetScalars(vtk_arr)
         self.VTKObject.Modified()
 
-    def set_vectors(self, vectors: Union[Sequence[Number], Number, np.ndarray],
-                    name: str, deep_copy=False):
+    def set_vectors(
+        self, vectors: Union[Sequence[Number], Number, np.ndarray], name: str, deep_copy=False
+    ):
         """Set the active vectors of this data attribute.
 
         Vectors are a quantity that has magnitude and direction, such
@@ -675,6 +693,17 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             ``False``, the data references the original array
             without copying it.
 
+        Notes
+        -----
+        PyVista and VTK treats vectors and scalars differently when
+        performing operations. Vector data, unlike scalar data, is
+        rotated along with the geometry when the DataSet is passed
+        through a transformation filter.
+
+        When adding non-directional data (such temperature values or
+        multi-component scalars like RGBA values), you can also use
+        :func:`DataSetAttributes.set_scalars`.
+
         Examples
         --------
         Add random vectors to a mesh as point data.
@@ -695,25 +724,13 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         Contains arrays :
             my-vectors              float64  (8, 3)               VECTORS
 
-        Notes
-        -----
-        PyVista and VTK treats vectors and scalars differently when
-        performing operations. Vector data, unlike scalar data, is
-        rotated along with the geometry when the DataSet is passed
-        through a transformation filter.
-
-        When adding non-directional data (such temperature values or
-        multi-component scalars like RGBA values), you can also use
-        :func:`DataSetAttributes.set_scalars`.
-
         """
         # prepare the array and add an attribute so that we can track this as a vector
         vtk_arr = self._prepare_array(vectors, name, deep_copy)
 
         n_comp = vtk_arr.GetNumberOfComponents()
         if n_comp != 3:
-            raise ValueError('Vector array should contain 3 components, got '
-                             f'{n_comp}')
+            raise ValueError(f'Vector array should contain 3 components, got {n_comp}')
 
         # check if there are current vectors, if so, we need to keep
         # this array around since setting active vectors will remove
@@ -727,8 +744,9 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
 
         self.VTKObject.Modified()
 
-    def _prepare_array(self, data: Union[Sequence[Number], Number, np.ndarray],
-                       name: str, deep_copy: bool) -> _vtk.vtkDataSet:
+    def _prepare_array(
+        self, data: Union[Sequence[Number], Number, np.ndarray], name: str, deep_copy: bool
+    ) -> _vtk.vtkDataSet:
         """Prepare an array to be added to this dataset."""
         if data is None:
             raise TypeError('``data`` cannot be None.')
@@ -763,9 +781,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             # If column order but not contiguous, transpose so that the
             # deep copy below does not happen.
             size = data.dtype.itemsize
-            if ((data.strides[1] / size == 3 and data.strides[2] / size == 1) or
-                (data.strides[1] / size == 1 and data.strides[2] / size == 3 and
-                 not data.flags.contiguous)):
+            if (data.strides[1] / size == 3 and data.strides[2] / size == 1) or (
+                data.strides[1] / size == 1
+                and data.strides[2] / size == 3
+                and not data.flags.contiguous
+            ):
                 data = data.transpose(0, 2, 1)
 
         # If array is not contiguous, make a deep copy that is contiguous
@@ -774,7 +794,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
 
         # Flatten array of matrices to array of vectors
         if len(shape) == 3:
-            data = data.reshape(shape[0], shape[1]*shape[2])
+            data = data.reshape(shape[0], shape[1] * shape[2])
 
         # Swap bytes from big to little endian.
         if data.dtype.byteorder == '>':
@@ -787,9 +807,14 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
 
         return helpers.convert_array(copy, name, deep=deep_copy)
 
-    def append(self, narray: Union[Sequence[Number], Number, np.ndarray],
-               name: str, deep_copy=False, active_vectors=False,
-               active_scalars=True) -> None:  # pragma: no cover
+    def append(
+        self,
+        narray: Union[Sequence[Number], Number, np.ndarray],
+        name: str,
+        deep_copy=False,
+        active_vectors=False,
+        active_scalars=True,
+    ) -> None:  # pragma: no cover
         """Add an array to this object.
 
         .. deprecated:: 0.32.0
@@ -808,7 +833,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             "  - `DataSetAttributes.set_scalars`\n"
             "  - `DataSetAttributes.set_vectors`\n"
             "  - The [] operator",
-            PyvistaDeprecationWarning
+            PyvistaDeprecationWarning,
         )
         if active_vectors:  # pragma: no cover
             raise ValueError('Use set_vectors to set vector data')
@@ -825,6 +850,10 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         key : str
             The name of the array to remove.
 
+        Notes
+        -----
+        You can also use the ``del`` statement.
+
         Examples
         --------
         Add a point data array to a DataSet and then remove it.
@@ -839,10 +868,6 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         >>> 'my_data' in mesh.point_data
         False
 
-        Notes
-        -----
-        You can also use the ``del`` statement.
-
         """
         if not isinstance(key, str):
             raise TypeError('Only strings are valid keys for DataSetAttributes.')
@@ -906,6 +931,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     def items(self) -> List[Tuple[str, pyvista_ndarray]]:
         """Return a list of (array name, array value) tuples.
 
+        Returns
+        -------
+        list
+            List of keys and values.
+
         Examples
         --------
         >>> import pyvista
@@ -922,6 +952,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     def keys(self) -> List[str]:
         """Return the names of the arrays as a list.
 
+        Returns
+        -------
+        list
+            List of keys.
+
         Examples
         --------
         >>> import pyvista
@@ -949,6 +984,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     def values(self) -> List[pyvista_ndarray]:
         """Return the arrays as a list.
 
+        Returns
+        -------
+        list
+            List of arrays.
+
         Examples
         --------
         >>> import pyvista
@@ -992,13 +1032,39 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
     def update(self, array_dict: Union[Dict[str, np.ndarray], 'DataSetAttributes']):
         """Update arrays in this object.
 
-        For each key, value given, add the pair, if it already exists,
+        For each key, value given, add the pair. If it already exists,
         update it.
 
         Parameters
         ----------
         array_dict : dict
-            A dictionary of (array name, numpy.ndarray)
+            A dictionary of ``(array name, numpy.ndarray)``.
+
+        Examples
+        --------
+        Add two arrays using ``update``.
+
+        >>> import numpy as np
+        >>> from pyvista import examples
+        >>> mesh = examples.load_uniform()
+        >>> n = len(mesh.point_data)
+        >>> arrays = {
+        ...     'foo': np.arange(mesh.n_points),
+        ...     'rand': np.random.random(mesh.n_points),
+        ... }
+        >>> mesh.point_data.update(arrays)
+        >>> mesh.point_data
+        pyvista DataSetAttributes
+        Association     : POINT
+        Active Scalars  : rand
+        Active Vectors  : None
+        Active Texture  : None
+        Active Normals  : None
+        Contains arrays :
+            Spatial Point Data      float64  (1000,)
+            foo                     int64    (1000,)
+            rand                    float64  (1000,)              SCALARS
+
         """
         for name, array in array_dict.items():
             self[name] = array.copy()
@@ -1111,6 +1177,10 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             Normals of this dataset attribute.  ``None`` if no
             normals have been set.
 
+        Notes
+        -----
+        Field data will have no normals.
+
         Examples
         --------
         First, compute cell normals.
@@ -1149,16 +1219,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         Contains arrays :
             Normals                 float64  (1, 3)               NORMALS
 
-        Notes
-        -----
-        Field data will have no normals.
-
         """
         self._raise_no_normals()
         vtk_normals = self.GetNormals()
         if vtk_normals is not None:
-            return pyvista_ndarray(vtk_normals, dataset=self.dataset,
-                                   association=self.association)
+            return pyvista_ndarray(vtk_normals, dataset=self.dataset, association=self.association)
         return None
 
     @active_normals.setter
@@ -1169,10 +1234,11 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
             raise ValueError('Normals must be a 2-dimensional array')
         valid_length = self.valid_array_len
         if normals.shape[0] != valid_length:
-            raise ValueError(f'Number of normals ({normals.shape[0]}) must match number of points ({valid_length})')
+            raise ValueError(
+                f'Number of normals ({normals.shape[0]}) must match number of points ({valid_length})'
+            )
         if normals.shape[1] != 3:
-            raise ValueError('Normals must have exactly 3 components,'
-                             f' not ({normals.shape[1]})')
+            raise ValueError(f'Normals must have exactly 3 components, not ({normals.shape[1]})')
 
         vtkarr = _vtk.numpyTovtkDataArray(normals, name='Normals')
         self.SetNormals(vtkarr)
@@ -1183,7 +1249,7 @@ class DataSetAttributes(_vtk.VTKObjectWrapper):
         """Return or set the name of the normals array.
 
         Returns
-        --------
+        -------
         str
             Name of the active normals array.
 
