@@ -12,7 +12,7 @@ except ImportError:  # pragma: no cover
     from vtk import vtkLight, vtkLightActor, vtkMatrix4x4
 
 from ..utilities.helpers import vtkmatrix_from_array
-from .tools import parse_color
+from .colors import Color, color_like
 
 
 class LightType(IntEnum):
@@ -44,7 +44,7 @@ class Light(vtkLight):
         has a transformation matrix.  See also the
         :py:attr:`focal_point` property.
 
-    color : str or 3-length sequence, optional
+    color : color_like, optional
         The color of the light. The ambient, diffuse and specular
         colors will all be set to this color on creation.
 
@@ -109,7 +109,7 @@ class Light(vtkLight):
 
     >>> import pyvista as pv
     >>> light = pv.Light(position=(10, 10, 10))
-    >>> light.diffuse_color = 1, 0, 0
+    >>> light.diffuse_color = 1.0, 0.0, 0.0
 
     Create a positional light at (0, 0, 3) with a cone angle of
     30, exponent of 20, and a visible actor.
@@ -124,11 +124,20 @@ class Light(vtkLight):
     CAMERA_LIGHT = LightType.CAMERA_LIGHT
     SCENE_LIGHT = LightType.SCENE_LIGHT
 
-    def __init__(self, position=None, focal_point=None, color=None,
-                 light_type='scene light', intensity=None,
-                 positional=None, cone_angle=None, show_actor=False,
-                 exponent=None, shadow_attenuation=None,
-                 attenuation_values=None):
+    def __init__(
+        self,
+        position=None,
+        focal_point=None,
+        color=None,
+        light_type='scene light',
+        intensity=None,
+        positional=None,
+        cone_angle=None,
+        show_actor=False,
+        exponent=None,
+        shadow_attenuation=None,
+        attenuation_values=None,
+    ):
         """Initialize the light."""
         super().__init__()
         self._renderers = []
@@ -148,19 +157,24 @@ class Light(vtkLight):
             # be forgiving: ignore spaces and case
             light_type_orig = light_type
             type_normalized = light_type.replace(' ', '').lower()
-            mapping = {'headlight': LightType.HEADLIGHT,
-                       'cameralight': LightType.CAMERA_LIGHT,
-                       'scenelight': LightType.SCENE_LIGHT}
+            mapping = {
+                'headlight': LightType.HEADLIGHT,
+                'cameralight': LightType.CAMERA_LIGHT,
+                'scenelight': LightType.SCENE_LIGHT,
+            }
             try:
                 light_type = mapping[type_normalized]
             except KeyError:
                 light_keys = ', '.join(mapping)
-                msg = (f'Invalid light_type "{light_type_orig}"\n'
-                       f'Choose from one of the following: {light_keys}')
+                msg = (
+                    f'Invalid light_type "{light_type_orig}"\n'
+                    f'Choose from one of the following: {light_keys}'
+                )
                 raise ValueError(msg) from None
         elif not isinstance(light_type, int):
-            raise TypeError('Parameter light_type must be int or str,'
-                            f' not {type(light_type).__name__}.')
+            raise TypeError(
+                f'Parameter light_type must be int or str, not {type(light_type).__name__}.'
+            )
         # LightType is an int subclass
 
         self.light_type = light_type
@@ -190,15 +204,24 @@ class Light(vtkLight):
 
     def __repr__(self):
         """Print a repr specifying the id of the light and its light type."""
-        return (f'<{self.__class__.__name__} ({self.light_type}) at {hex(id(self))}>')
+        return f'<{self.__class__.__name__} ({self.light_type}) at {hex(id(self))}>'
 
     def __eq__(self, other):
         """Compare whether the relevant attributes of two lights are equal."""
         # attributes which are native python types and thus implement __eq__
         native_attrs = [
-            'light_type', 'position', 'focal_point', 'ambient_color',
-            'diffuse_color', 'specular_color', 'intensity', 'on',
-            'positional', 'exponent', 'cone_angle', 'attenuation_values',
+            'light_type',
+            'position',
+            'focal_point',
+            'ambient_color',
+            'diffuse_color',
+            'specular_color',
+            'intensity',
+            'on',
+            'positional',
+            'exponent',
+            'cone_angle',
+            'attenuation_values',
             'shadow_attenuation',
         ]
         for attr in native_attrs:
@@ -261,7 +284,7 @@ class Light(vtkLight):
 
             * ``color='white'``
             * ``color='w'``
-            * ``color=[1, 1, 1]``
+            * ``color=[1.0, 1.0, 1.0]``
             * ``color='#FFFFFF'``
 
         Examples
@@ -272,15 +295,15 @@ class Light(vtkLight):
         >>> light = pyvista.Light()
         >>> light.ambient_color = 'red'
         >>> light.ambient_color
-        (1.0, 0.0, 0.0)
+        Color(name='red', hex='#ff0000ff')
 
         """
-        return self.GetAmbientColor()
+        return Color(self.GetAmbientColor())
 
     @ambient_color.setter
-    def ambient_color(self, color):
+    def ambient_color(self, color: color_like):
         """Set the ambient color of the light."""
-        self.SetAmbientColor(parse_color(color)[:3])
+        self.SetAmbientColor(Color(color).float_rgb)
 
     @property
     def diffuse_color(self):
@@ -291,7 +314,7 @@ class Light(vtkLight):
 
             * ``color='white'``
             * ``color='w'``
-            * ``color=[1, 1, 1]``
+            * ``color=[1.0, 1.0, 1.0]``
             * ``color='#FFFFFF'``
 
         Examples
@@ -300,17 +323,17 @@ class Light(vtkLight):
 
         >>> import pyvista as pv
         >>> light = pv.Light()
-        >>> light.diffuse_color = (0, 0, 1)
+        >>> light.diffuse_color = (0.0, 0.0, 1.0)
         >>> light.diffuse_color
-        (0.0, 0.0, 1.0)
+        Color(name='blue', hex='#0000ffff')
 
         """
-        return self.GetDiffuseColor()
+        return Color(self.GetDiffuseColor())
 
     @diffuse_color.setter
-    def diffuse_color(self, color):
+    def diffuse_color(self, color: color_like):
         """Set the diffuse color of the light."""
-        self.SetDiffuseColor(parse_color(color)[:3])
+        self.SetDiffuseColor(Color(color).float_rgb)
 
     @property
     def specular_color(self):
@@ -321,7 +344,7 @@ class Light(vtkLight):
 
             * ``color='white'``
             * ``color='w'``
-            * ``color=[1, 1, 1]``
+            * ``color=[1.0, 1.0, 1.0]``
             * ``color='#FFFFFF'``
 
         Examples
@@ -332,15 +355,15 @@ class Light(vtkLight):
         >>> light = pv.Light()
         >>> light.specular_color = '#00FF00'
         >>> light.specular_color
-        (0.0, 1.0, 0.0)
+        Color(name='lime', hex='#00ff00ff')
 
         """
-        return self.GetSpecularColor()
+        return Color(self.GetSpecularColor())
 
     @specular_color.setter
-    def specular_color(self, color):
+    def specular_color(self, color: color_like):
         """Set the specular color of the light."""
-        self.SetSpecularColor(parse_color(color)[:3])
+        self.SetSpecularColor(Color(color).float_rgb)
 
     @property
     def position(self):
@@ -770,8 +793,9 @@ class Light(vtkLight):
             try:
                 trans = vtkmatrix_from_array(matrix)
             except ValueError:
-                raise ValueError('Transformation matrix must be '
-                                 'a 4-by-4 matrix or array-like.') from None
+                raise ValueError(
+                    'Transformation matrix must be a 4-by-4 matrix or array-like.'
+                ) from None
         self.SetTransformMatrix(trans)
 
     @property
@@ -833,8 +857,9 @@ class Light(vtkLight):
         """
         if not isinstance(ltype, int):
             # note that LightType is an int subclass
-            raise TypeError('Light type must be an integer subclass instance,'
-                            f' got {ltype} instead.')
+            raise TypeError(
+                f'Light type must be an integer subclass instance, got {ltype} instead.'
+            )
         self.SetLightType(ltype)
 
     @property
@@ -959,11 +984,7 @@ class Light(vtkLight):
         self.focal_point = (0, 0, 0)
         theta = np.radians(90 - elev)
         phi = np.radians(azim)
-        self.position = (
-            np.sin(theta) * np.cos(phi),
-            np.sin(theta) * np.sin(phi),
-            np.cos(theta)
-        )
+        self.position = (np.sin(theta) * np.cos(phi), np.sin(theta) * np.sin(phi), np.cos(theta))
 
     def copy(self, deep=True):
         """Return a shallow or a deep copy of the light.
@@ -1101,8 +1122,9 @@ class Light(vtkLight):
 
         """
         if not isinstance(vtk_light, vtkLight):
-            raise TypeError('Expected vtk.vtkLight object, got '
-                            f'{type(vtk_light).__name__} instead.')
+            raise TypeError(
+                f'Expected vtk.vtkLight object, got {type(vtk_light).__name__} instead.'
+            )
 
         light = cls()
         light.light_type = vtk_light.GetLightType()  # resets transformation matrix!
