@@ -1,5 +1,6 @@
 """Module managing picking events."""
 
+from functools import partial
 import logging
 import weakref
 
@@ -10,11 +11,22 @@ from pyvista import _vtk
 from pyvista.utilities import try_callback
 
 
+def _launch_pick_event(interactor, event):
+    """Create a Pick event based on coordinate or left-click."""
+    click_x, click_y = interactor.GetEventPosition()
+    click_z = 0
+
+    picker = interactor.GetPicker()
+    renderer = interactor.GetInteractorStyle()._parent()._plotter.renderer
+    picker.Pick(click_x, click_y, click_z, renderer)
+
+
 class PickingHelper:
     """An internal class to hold picking related features."""
 
     picked_cells = None
-    picked_point = None
+    _picked_point = None
+    _picked_mesh = None
     picked_path = None
     picked_geodesic = None
     picked_horizon = None
@@ -30,10 +42,176 @@ class PickingHelper:
         """
         return self.renderer.get_pick_position()
 
-    def enable_cell_picking(self, mesh=None, callback=None, through=True,
-                            show=True, show_message=True, style='wireframe',
-                            line_width=5, color='pink', font_size=18,
-                            start=False, **kwargs):
+    def enable_mesh_picking(
+        self,
+        callback=None,
+        show=True,
+        show_message=True,
+        style='wireframe',
+        line_width=5,
+        color='pink',
+        font_size=18,
+        left_clicking=False,
+        **kwargs,
+    ):
+        """Enable picking of a mesh.
+
+        Parameters
+        ----------
+        callback : function, optional
+            When input, calls this function after a selection is made. The
+            ``mesh`` is input as the first parameter to this function.
+
+        show : bool, optional
+            Show the selection interactively. Best when combined with
+            ``left_clicking``.
+
+        show_message : bool or str, optional
+            Show the message about how to use the mesh picking tool. If this
+            is a string, that will be the message shown.
+
+        style : str, optional
+            Visualization style of the selection.  Defaults to
+            ``'wireframe'``. One of the following:
+
+            * ``'surface'``
+            * ``'wireframe'``
+            * ``'points'``
+
+        line_width : float, optional
+            Thickness of selected mesh edges. Default 5.
+
+        color : color_like, optional
+            The color of the selected mesh when shown.
+
+        font_size : int, optional
+            Sets the font size of the message.
+
+        left_clicking : bool, optional
+            When ``True``, meshes can be picked by clicking the left
+            mousebutton.  Default to ``False``.
+
+            .. note::
+               If enabled, left-clicking will **not** display the bounding box
+               around the picked point.
+
+        **kwargs : dict, optional
+            All remaining keyword arguments are used to control how
+            the picked path is interactively displayed.
+
+        Returns
+        -------
+        vtk.vtkPropPicker
+            Property picker.
+
+        Examples
+        --------
+        Add a sphere and a cube to a plot and enable mesh picking. Enable
+        ``left_clicking`` to immediately start picking on the left click and
+        disable showing the box. You can still press the ``p`` key to select
+        meshes.
+
+        >>> import pyvista as pv
+        >>> mesh = pv.Sphere(center=(1, 0, 0))
+        >>> cube = pv.Cube()
+        >>> pl = pv.Plotter()
+        >>> _ = pl.add_mesh(mesh)
+        >>> _ = pl.add_mesh(cube)
+        >>> _ = pl.enable_mesh_picking(left_clicking=True)
+
+        See :ref:`mesh_picking_example` for a full example using this method.
+
+        """
+
+        def end_pick_call_back(picked, event):
+            is_valid_selection = False
+            self_ = weakref.ref(self)
+
+            actor = picked.GetActor()
+            if actor:
+                mesh = actor.GetMapper().GetInput()
+                is_valid_selection = True
+
+            if is_valid_selection:
+                self_()._picked_mesh = mesh
+
+            if callback and is_valid_selection:
+                try_callback(callback, mesh)
+
+            if show and is_valid_selection:
+
+                # Select the renderer where the mesh is added.
+                active_renderer_index = self_().renderers._active_index
+                for index in range(len(self.renderers)):
+                    renderer = self.renderers[index]
+                    for actor in renderer._actors.values():
+                        mapper = actor.GetMapper()
+                        if isinstance(mapper, _vtk.vtkDataSetMapper) and mapper.GetInput() == mesh:
+                            loc = self_().renderers.index_to_loc(index)
+                            self_().subplot(*loc)
+                            break
+
+                # Use try in case selection is empty or invalid
+                try:
+                    self_().add_mesh(
+                        mesh,
+                        name='_mesh_picking_selection',
+                        style=style,
+                        color=color,
+                        line_width=line_width,
+                        pickable=False,
+                        reset_camera=False,
+                        **kwargs,
+                    )
+                except Exception as e:  # pragma: no cover
+                    logging.warning("Unable to show mesh when picking:\n\n%s", str(e))
+
+                # Reset to the active renderer.
+                loc = self_().renderers.index_to_loc(active_renderer_index)
+                self_().subplot(*loc)
+
+                # render here prior to running the callback
+                self_().render()
+            elif not is_valid_selection:
+                self.remove_actor('_mesh_picking_selection')
+                self_()._picked_mesh = None
+
+        # add on-screen message about point-selection
+        if show_message:
+            if show_message is True:
+                show_message = "\nPress P to pick a single dataset under the mouse pointer."
+                if left_clicking:
+                    show_message += "\nor click to select a dataset under the mouse pointer."
+
+            self.add_text(str(show_message), font_size=font_size, name='_mesh_picking_message')
+
+        if left_clicking:
+            self.iren.interactor.AddObserver(
+                "LeftButtonPressEvent",
+                partial(try_callback, _launch_pick_event),
+            )
+
+        picker = _vtk.vtkPropPicker()
+        picker.AddObserver(_vtk.vtkCommand.EndPickEvent, end_pick_call_back)
+        self.enable_trackball_style()
+        self.iren.set_picker(picker)
+
+        return picker
+
+    def enable_cell_picking(
+        self,
+        mesh=None,
+        callback=None,
+        through=True,
+        show=True,
+        show_message=True,
+        style='wireframe',
+        line_width=5,
+        color='pink',
+        font_size=18,
+        start=False,
+        **kwargs,
+    ):
         """Enable picking at cells.
 
         Press ``"r"`` to enable retangle based selection.  Press
@@ -41,7 +219,7 @@ class PickingHelper:
         ``self.picked_cells``. Also press ``"p"`` to pick a single
         cell under the mouse location.
 
-        When using ``through=False``, and multiple meshes are being
+        When using ``through=False``, and multiple cells are being
         picked, the picked cells in ````self.picked_cells`` will be a
         :class:`MultiBlock` dataset for each mesh's selection.
 
@@ -73,14 +251,14 @@ class PickingHelper:
             through the mesh. When ``False``, the picker will select
             only visible cells on the mesh's surface.
 
-        show : bool
+        show : bool, optional
             Show the selection interactively.
 
         show_message : bool or str, optional
             Show the message about how to use the cell picking tool. If this
             is a string, that will be the message shown.
 
-        style : str
+        style : str, optional
             Visualization style of the selection.  One of the
             following: ``style='surface'``, ``style='wireframe'``, or
             ``style='points'``.  Defaults to ``'wireframe'``.
@@ -88,8 +266,8 @@ class PickingHelper:
         line_width : float, optional
             Thickness of selected mesh edges. Default 5.
 
-        color : str, optional
-            The color of the selected mesh is shown.
+        color : color_like, optional
+            The color of the selected mesh when shown.
 
         font_size : int, optional
             Sets the font size of the message.
@@ -101,11 +279,24 @@ class PickingHelper:
             All remaining keyword arguments are used to control how
             the selection is interactively displayed.
 
+        Examples
+        --------
+        Add a mesh and a cube to a plot and enable cell picking.
+
+        >>> import pyvista as pv
+        >>> mesh = pv.Sphere(center=(1, 0, 0))
+        >>> cube = pv.Cube()
+        >>> pl = pv.Plotter()
+        >>> _ = pl.add_mesh(mesh)
+        >>> _ = pl.add_mesh(cube)
+        >>> _ = pl.enable_cell_picking(left_clicking=True)
+
         """
         if mesh is None:
             if not hasattr(self, 'mesh') or self.mesh is None:
-                raise AttributeError('Input a mesh into the Plotter class first or '
-                                     'or set it in this function')
+                raise AttributeError(
+                    'Input a mesh into the Plotter class first or or set it in this function'
+                )
             mesh = self.mesh
         self_ = weakref.ref(self)
 
@@ -136,10 +327,16 @@ class PickingHelper:
                             break
 
                 # Use try in case selection is empty
-                self_().add_mesh(picked, name='_cell_picking_selection',
-                                 style=style, color=color,
-                                 line_width=line_width, pickable=False,
-                                 reset_camera=False, **kwargs)
+                self_().add_mesh(
+                    picked,
+                    name='_cell_picking_selection',
+                    style=style,
+                    color=color,
+                    line_width=line_width,
+                    pickable=False,
+                    reset_camera=False,
+                    **kwargs,
+                )
 
                 # Reset to the active renderer.
                 loc = self_().renderers.index_to_loc(active_renderer_index)
@@ -178,13 +375,17 @@ class PickingHelper:
 
                 for node in range(selection.GetNumberOfNodes()):
                     selection_node = selection.GetNode(node)
-                    if selection_node is None:
+                    if selection_node is None:  # pragma: no cover
                         # No selection
                         continue
                     cids = pyvista.convert_array(selection_node.GetSelectionList())
                     actor = selection_node.GetProperties().Get(_vtk.vtkSelectionNode.PROP())
-                    if actor.GetProperty().GetRepresentation() != 2:  # surface
-                        logging.warning("Display representations other than `surface` will result in incorrect results.")
+
+                    # if not a surface
+                    if actor.GetProperty().GetRepresentation() != 2:  # pragma: no cover
+                        logging.warning(
+                            "Display representations other than `surface` will result in incorrect results."
+                        )
                     smesh = actor.GetMapper().GetInputAsDataSet()
                     smesh = smesh.copy()
                     smesh["original_cell_ids"] = np.arange(smesh.n_cells)
@@ -227,10 +428,176 @@ class PickingHelper:
         if start:
             self.iren._style_class.StartSelect()
 
-    def enable_point_picking(self, callback=None, show_message=True,
-                             font_size=18, color='pink', point_size=10,
-                             use_mesh=False, show_point=True, tolerance=0.025,
-                             pickable_window=False, **kwargs):
+    @property
+    def picked_mesh(self):
+        """Return the picked mesh.
+
+        This returns the picked mesh after selecting a mesh with
+        :func:`<enable_mesh_picking> pyvista.Plotter.enable_mesh_picking` or
+        :func:`<enable_point_picking> pyvista.Plotter.enable_point_picking`.
+
+        Returns
+        -------
+        pyvista.DataSet or None
+            Picked mesh if available.
+
+        """
+        return self._picked_mesh
+
+    @property
+    def picked_point(self):
+        """Return the picked point.
+
+        This returns the picked point after selecting a point.
+
+        Returns
+        -------
+        numpy.ndarray or None
+            Picked point if available.
+
+        """
+        return self._picked_point
+
+    def enable_surface_picking(
+        self,
+        callback=None,
+        show_message=True,
+        font_size=18,
+        color='pink',
+        show_point=True,
+        point_size=10,
+        tolerance=0.025,
+        pickable_window=False,
+        left_clicking=False,
+        **kwargs,
+    ):
+        """Enable picking of a mesh.
+
+        Parameters
+        ----------
+        callback : function, optional
+            When input, calls this function after a selection is made. The
+            ``mesh`` is input as the first parameter to this function.
+
+        show_message : bool or str, optional
+            Show the message about how to use the mesh picking tool. If this
+            is a string, that will be the message shown.
+
+        font_size : int, optional
+            Sets the font size of the message.
+
+        color : color_like, optional
+            The color of the selected mesh when shown.
+
+        show_point : bool, optional
+            Show the selection interactively. Default ``True``.
+
+        point_size : int, optional
+            Size of picked points if ``show_point`` is
+            ``True``. Default 10.
+
+        tolerance : float, optional
+            Specify tolerance for performing pick operation. Tolerance
+            is specified as fraction of rendering window
+            size. Rendering window size is measured across diagonal.
+
+        pickable_window : bool, optional
+            When ``True``, points in the 3D window are pickable. Default to ``False``.
+
+        left_clicking : bool, optional
+            When ``True``, meshes can be picked by clicking the left
+            mousebutton.  Default to ``False``.
+
+            .. note::
+               If enabled, left-clicking will **not** display the bounding box
+               around the picked mesh.
+
+        **kwargs : dict, optional
+            All remaining keyword arguments are used to control how
+            the picked path is interactively displayed.
+
+        Returns
+        -------
+        vtk.vtkPropPicker
+            Property picker.
+
+        Examples
+        --------
+        Add a cube to a plot and enable cell picking. Enable ``left_clicking``
+        to immediately start picking on the left click and disable showing the
+        box. You can still press the ``p`` key to select meshes.
+
+        >>> import pyvista as pv
+        >>> cube = pv.Cube()
+        >>> pl = pv.Plotter()
+        >>> _ = pl.add_mesh(cube)
+        >>> _ = pl.enable_surface_picking(left_clicking=True)
+
+        See :ref:`surface_picking_example` for a full example using this method.
+
+        """
+
+        def _end_pick_event(picker, event):
+
+            picked_point_id = picker.GetPointId()
+            if not pickable_window and picked_point_id < 0:
+                self._picked_point = None
+                return
+
+            self._picked_point = np.array(picker.GetPickPosition())
+            self._picked_mesh = picker.GetDataSet()
+            if show_point:
+                self.add_mesh(
+                    self.picked_point,
+                    color=color,
+                    point_size=point_size,
+                    name='_picked_point',
+                    pickable=False,
+                    reset_camera=False,
+                    **kwargs,
+                )
+            if callable(callback):
+                try_callback(callback, self.picked_point)
+
+        picker = _vtk.vtkCellPicker()
+        picker.SetTolerance(tolerance)
+        self.picker = picker
+        picker.AddObserver(_vtk.vtkCommand.EndPickEvent, _end_pick_event)
+
+        self.enable_trackball_style()
+        self.iren.set_picker(picker)
+
+        if left_clicking:
+            self.iren.interactor.AddObserver(
+                "LeftButtonPressEvent",
+                partial(try_callback, _launch_pick_event),
+            )
+
+        # add on-screen message about point-selection
+        if show_message:
+            if show_message is True:
+                show_message = "\nPress P to pick a point on the surface under the mouse pointer."
+                if left_clicking:
+                    show_message += "\nor click to select a point under the mouse pointer."
+
+            self.add_text(str(show_message), font_size=font_size, name='_surf_picking_message')
+
+        return picker
+
+    def enable_point_picking(
+        self,
+        callback=None,
+        show_message=True,
+        font_size=18,
+        color='pink',
+        point_size=10,
+        use_mesh=False,
+        show_point=True,
+        tolerance=0.025,
+        pickable_window=False,
+        left_clicking=False,
+        **kwargs,
+    ):
         """Enable picking at points.
 
         Enable picking a point at the mouse location in the render
@@ -256,8 +623,8 @@ class PickingHelper:
         font_size : int, optional
             Sets the size of the message.
 
-        color : str, optional
-            The color of the selected mesh is shown.
+        color : color_like, optional
+            The color of the selected mesh when shown.
 
         point_size : int, optional
             Size of picked points if ``show_point`` is
@@ -277,7 +644,12 @@ class PickingHelper:
             size. Rendering window size is measured across diagonal.
 
         pickable_window : bool, optional
-            When True, points in the 3D window are pickable. Default to ``True``.
+            When ``True``, points in the 3D window are pickable. Default to ``False``.
+
+        left_clicking : bool, optional
+            When ``True``, points can be picked by clicking the left mousebutton.
+            Default to ``False``. Note, if enabled, left-clicking will **not**
+            display the bounding box around the picked mesh.
 
         **kwargs : dict, optional
             All remaining keyword arguments are used to control how
@@ -303,13 +675,19 @@ class PickingHelper:
             if (not pickable_window) and (picked_point_id < 0):
                 return None
 
-            self.picked_point = np.array(picker.GetPickPosition())
-            self.picked_mesh = picker.GetDataSet()
+            self._picked_point = np.array(picker.GetPickPosition())
+            self._picked_mesh = picker.GetDataSet()
             self.picked_point_id = picked_point_id
             if show_point:
-                self.add_mesh(self.picked_point, color=color,
-                              point_size=point_size, name='_picked_point',
-                              pickable=False, reset_camera=False, **kwargs)
+                self.add_mesh(
+                    self.picked_point,
+                    color=color,
+                    point_size=point_size,
+                    name='_picked_point',
+                    pickable=False,
+                    reset_camera=False,
+                    **kwargs,
+                )
             if callable(callback):
                 if use_mesh:
                     try_callback(callback, self.picked_mesh, self.picked_point_id)
@@ -324,17 +702,32 @@ class PickingHelper:
         self.enable_trackball_style()
         self.iren.set_picker(point_picker)
 
+        if left_clicking:
+            self.iren.interactor.AddObserver(
+                "LeftButtonPressEvent",
+                partial(try_callback, _launch_pick_event),
+            )
+
         # Now add text about cell-selection
         if show_message:
-            if show_message is True:
+            if show_message is True and left_clicking:
+                show_message = "Left-click or press P to pick under the mouse"
+            elif show_message is True:
                 show_message = "Press P to pick under the mouse"
-            self.add_text(str(show_message), font_size=font_size,
-                          name='_point_picking_message')
+            self.add_text(str(show_message), font_size=font_size, name='_point_picking_message')
 
-    def enable_path_picking(self, callback=None, show_message=True,
-                            font_size=18, color='pink', point_size=10,
-                            line_width=5, show_path=True, tolerance=0.025,
-                            **kwargs):
+    def enable_path_picking(
+        self,
+        callback=None,
+        show_message=True,
+        font_size=18,
+        color='pink',
+        point_size=10,
+        line_width=5,
+        show_path=True,
+        tolerance=0.025,
+        **kwargs,
+    ):
         """Enable picking at paths.
 
         This is a convenience method for :func:`enable_point_picking
@@ -358,8 +751,8 @@ class PickingHelper:
         font_size : int, optional
             Sets the size of the message.
 
-        color : str, optional
-            The color of the selected mesh is shown.
+        color : color_like, optional
+            The color of the selected mesh when shown.
 
         point_size : int, optional
             Size of picked points if ``show_path`` is
@@ -385,9 +778,6 @@ class PickingHelper:
         kwargs.setdefault('pickable', False)
 
         def make_line_cells(n_points):
-            # cells = np.full((n_points-1, 3), 2, dtype=np.int_)
-            # cells[:, 1] = np.arange(0, n_points-1, dtype=np.int_)
-            # cells[:, 2] = np.arange(1, n_points, dtype=np.int_)
             cells = np.arange(0, n_points, dtype=np.int_)
             cells = np.insert(cells, 0, n_points)
             return cells
@@ -403,9 +793,15 @@ class PickingHelper:
             self.picked_path = pyvista.PolyData(np.array(the_points))
             self.picked_path.lines = make_line_cells(len(the_points))
             if show_path:
-                self.add_mesh(self.picked_path, color=color, name='_picked_path',
-                              line_width=line_width, point_size=point_size,
-                              reset_camera=False, **kwargs)
+                self.add_mesh(
+                    self.picked_path,
+                    color=color,
+                    name='_picked_path',
+                    line_width=line_width,
+                    point_size=point_size,
+                    reset_camera=False,
+                    **kwargs,
+                )
             if callable(callback):
                 try_callback(callback, self.picked_path)
 
@@ -418,16 +814,28 @@ class PickingHelper:
         if show_message is True:
             show_message = "Press P to pick under the mouse\nPress C to clear"
 
-        self.enable_point_picking(callback=_the_callback,
-                                  use_mesh=True, font_size=font_size,
-                                  show_message=show_message,
-                                  show_point=False,
-                                  tolerance=tolerance)
+        self.enable_point_picking(
+            callback=_the_callback,
+            use_mesh=True,
+            font_size=font_size,
+            show_message=show_message,
+            show_point=False,
+            tolerance=tolerance,
+        )
 
-    def enable_geodesic_picking(self, callback=None, show_message=True,
-                                font_size=18, color='pink', point_size=10,
-                                line_width=5, tolerance=0.025, show_path=True,
-                                keep_order=True, **kwargs):
+    def enable_geodesic_picking(
+        self,
+        callback=None,
+        show_message=True,
+        font_size=18,
+        color='pink',
+        point_size=10,
+        line_width=5,
+        tolerance=0.025,
+        show_path=True,
+        keep_order=True,
+        **kwargs,
+    ):
         """Enable picking at geodesic paths.
 
         This is a convenience method for ``enable_point_picking`` to
@@ -451,8 +859,8 @@ class PickingHelper:
         font_size : int, optional
             Sets the size of the message.
 
-        color : str, optional
-            The color of the selected mesh is shown.
+        color : color_like, optional
+            The color of the selected mesh when shown.
 
         point_size : int, optional
             Size of picked points if ``show_path`` is
@@ -507,19 +915,27 @@ class PickingHelper:
                 locator.BuildLocator()
                 start_idx = locator.FindClosestPoint(mesh.points[self._last_picked_idx])
                 end_idx = locator.FindClosestPoint(point)
-                self.picked_geodesic += surface.geodesic(start_idx, end_idx,
-                                                         keep_order=keep_order)
+                self.picked_geodesic += surface.geodesic(start_idx, end_idx, keep_order=keep_order)
                 if keep_order:
                     # it makes sense to remove adjacent duplicate points
-                    self.picked_geodesic.clean(inplace=True, lines_to_points=False,
-                                               polys_to_lines=False,
-                                               strips_to_polys=False)
+                    self.picked_geodesic.clean(
+                        inplace=True,
+                        lines_to_points=False,
+                        polys_to_lines=False,
+                        strips_to_polys=False,
+                    )
             self._last_picked_idx = idx
 
             if show_path:
-                self.add_mesh(self.picked_geodesic, color=color, name='_picked_path',
-                              line_width=line_width, point_size=point_size,
-                              reset_camera=False, **kwargs)
+                self.add_mesh(
+                    self.picked_geodesic,
+                    color=color,
+                    name='_picked_path',
+                    line_width=line_width,
+                    point_size=point_size,
+                    reset_camera=False,
+                    **kwargs,
+                )
             if callable(callback):
                 try_callback(callback, self.picked_geodesic)
 
@@ -532,17 +948,30 @@ class PickingHelper:
         if show_message is True:
             show_message = "Press P to pick under the mouse\nPress C to clear"
 
-        self.enable_point_picking(callback=_the_callback,
-                                  use_mesh=True, font_size=font_size,
-                                  show_message=show_message,
-                                  tolerance=tolerance,
-                                  show_point=False)
+        self.enable_point_picking(
+            callback=_the_callback,
+            use_mesh=True,
+            font_size=font_size,
+            show_message=show_message,
+            tolerance=tolerance,
+            show_point=False,
+        )
 
-    def enable_horizon_picking(self, callback=None, normal=(0,0,1),
-                               width=None, show_message=True,
-                               font_size=18, color='pink', point_size=10,
-                               line_width=5, show_path=True, opacity=0.75,
-                               show_horizon=True, **kwargs):
+    def enable_horizon_picking(
+        self,
+        callback=None,
+        normal=(0, 0, 1),
+        width=None,
+        show_message=True,
+        font_size=18,
+        color='pink',
+        point_size=10,
+        line_width=5,
+        show_path=True,
+        opacity=0.75,
+        show_horizon=True,
+        **kwargs,
+    ):
         """Enable horizon picking.
 
         Helper for the ``enable_path_picking`` method to also show a
@@ -571,7 +1000,7 @@ class PickingHelper:
         font_size : int, optional
             Sets the font size of the message.
 
-        color : str, optional
+        color : color_like, optional
             The color of the horizon surface if shown.
 
         point_size : int, optional
@@ -607,17 +1036,28 @@ class PickingHelper:
             self.picked_horizon = path.ribbon(normal=normal, width=width)
 
             if show_horizon:
-                self.add_mesh(self.picked_horizon, name=name, color=color,
-                              opacity=opacity, pickable=False,
-                              reset_camera=False)
+                self.add_mesh(
+                    self.picked_horizon,
+                    name=name,
+                    color=color,
+                    opacity=opacity,
+                    pickable=False,
+                    reset_camera=False,
+                )
 
             if callable(callback):
                 try_callback(callback, path)
 
-        self.enable_path_picking(callback=_the_callback,
-            show_message=show_message, font_size=font_size, color=color,
-            point_size=point_size, line_width=line_width, show_path=show_path,
-            **kwargs)
+        self.enable_path_picking(
+            callback=_the_callback,
+            show_message=show_message,
+            font_size=font_size,
+            color=color,
+            point_size=point_size,
+            line_width=line_width,
+            show_path=show_path,
+            **kwargs,
+        )
 
     def pick_click_position(self):
         """Get corresponding click location in the 3D plot.
